/****************************************************************************
** Meta object code from reading C++ file 'client_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lxqt-globalkeys-2.3.0/client/client_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'client_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalKeyShortcut::ClientImpl::qt_create_metaobjectdata<qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalKeyShortcut::ClientImpl",
        "emitShortcutGrabbed",
        "",
        "emitGrabShortcutFailed",
        "emitGrabShortcutCancelled",
        "emitGrabShortcutTimedout",
        "emitDaemonDisappeared",
        "emitDaemonAppeared",
        "emitDaemonPresenceChanged",
        "grabShortcutFinished",
        "QDBusPendingCallWatcher*",
        "call",
        "daemonDisappeared",
        "daemonAppeared",
        "registrationFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'emitShortcutGrabbed'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'emitGrabShortcutFailed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitGrabShortcutCancelled'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitGrabShortcutTimedout'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitDaemonDisappeared'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitDaemonAppeared'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitDaemonPresenceChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'grabShortcutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'daemonDisappeared'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'daemonAppeared'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'registrationFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClientImpl, qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GlobalKeyShortcut::ClientImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>.metaTypes,
    nullptr
} };

void GlobalKeyShortcut::ClientImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClientImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->emitShortcutGrabbed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->emitGrabShortcutFailed(); break;
        case 2: _t->emitGrabShortcutCancelled(); break;
        case 3: _t->emitGrabShortcutTimedout(); break;
        case 4: _t->emitDaemonDisappeared(); break;
        case 5: _t->emitDaemonAppeared(); break;
        case 6: _t->emitDaemonPresenceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->grabShortcutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 8: _t->daemonDisappeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->daemonAppeared((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->registrationFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)(const QString & )>(_a, &ClientImpl::emitShortcutGrabbed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)()>(_a, &ClientImpl::emitGrabShortcutFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)()>(_a, &ClientImpl::emitGrabShortcutCancelled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)()>(_a, &ClientImpl::emitGrabShortcutTimedout, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)()>(_a, &ClientImpl::emitDaemonDisappeared, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)()>(_a, &ClientImpl::emitDaemonAppeared, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClientImpl::*)(bool )>(_a, &ClientImpl::emitDaemonPresenceChanged, 6))
            return;
    }
}

const QMetaObject *GlobalKeyShortcut::ClientImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalKeyShortcut::ClientImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17GlobalKeyShortcut10ClientImplE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GlobalKeyShortcut::ClientImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void GlobalKeyShortcut::ClientImpl::emitShortcutGrabbed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void GlobalKeyShortcut::ClientImpl::emitGrabShortcutFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GlobalKeyShortcut::ClientImpl::emitGrabShortcutCancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GlobalKeyShortcut::ClientImpl::emitGrabShortcutTimedout()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GlobalKeyShortcut::ClientImpl::emitDaemonDisappeared()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GlobalKeyShortcut::ClientImpl::emitDaemonAppeared()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GlobalKeyShortcut::ClientImpl::emitDaemonPresenceChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
